##  Exporting Diagrams in Edit Mode
To export the diagram in the Edit mode, follow these steps:
  1. Go to File> Export as from the menu above the toolbar.
  2. Select your preferred file format.


Once the option is selected, your browser will download an XML file with the diagram's name.
